@@ -18,6 +18,7 @@ from airflow_commons.utils.bigquery.bigquery_utils import (
     select,
     query_information_schema,
     get_table_ref,
+    get_primitive_column_list,
 )
 from airflow_commons.utils.file_utils import read_sql
 from airflow_commons.utils.bigquery.sql_utils import (
@@ -429,15 +430,18 @@ def archive(
             "Invalid archive mode:{}. Acceptable column names are ".format(mode)
             + COMMA.join(i for i in ARCHIVE_MODES)
         )
-    if primary_keys is None:
-        primary_keys = ARCHIVE_DEFAULT_PRIMARY_KEYS
+    client = connect(service_account_file=service_account_file)
+    if primary_keys is None or primary_keys == []:
+        primary_keys = get_primitive_column_list(
+            client, project_id, source_dataset, source_table
+        )
     source_statement_params = dict()
     source_statement_params["project_id"] = project_id
     source_statement_params["source_dataset"] = source_dataset
     source_statement_params["source_table"] = source_table
     source_statement_params["archive_date"] = archive_date
     source_statement_params["source_partition_field"] = get_time_partition_field(
-        client=connect(service_account_file=service_account_file),
+        client=client,
         dataset_id=source_dataset,
         table_id=source_table,
     )
